/*
    file comment
    multi line
*/

// class comments_file_variant1 single line comment
class comments_file_variant1 {};
